declare const _exports: {
    /**
     * Creates an inheritance relation between the child and the parent, adding a 'super_' attribute to the
     * child, and setting up the child prototype.
     *
     * @param {Function} child - The target object to create parent references for,.
     * @param {Function} base - The parent association to assign to the provided child definition.
     * @returns {*}
     */
    inherit: (child: Function, base: Function) => any;
    /**
     * Creates a hidden property on an object, which can be changed, but is not enumerable.
     *
     * @param {Object} obj
     * @param {String} name
     * @param {*} prop
     * @returns {*}
     */
    assignHidden: (obj: any, name: string, prop: any) => any;
    /**
     * Creates a property on an object, with the given type.
     *
     * @param {Object} obj
     * @param {String} name
     * @param {Property} Prop
     * @param {*} [fallback]
     * @returns {Prop|undefined}
     */
    createDefined: (obj: any, name: string, Prop: any, fallback?: any) => any | undefined;
    /**
     * Merges defined keys from the target object onto the source object.
     *
     * @param {Object} target
     * @param {Object} source
     * @returns {Object}
     */
    mergeDefined: (target: any, source: any) => any;
    /**
     * Returns the value of a property if defined in object, else the default
     *
     * @param {Object} obj
     * @param {String} prop
     * @param {*=} def
     *
     * @returns {*}
     */
    getOwn: (obj: any, prop: string, def?: any | undefined) => any;
    /**
     * Creates a clone of an object, but uses the toJSON method if available.
     *
     * @param {Object} obj
     * @returns {*}
     */
    cloneElement: (obj: any) => any;
    isNumeric: (n: any) => boolean;
    assign: any;
    clone: any;
    isArray: any;
    isEmpty: any;
    isFunction: any;
    isNaN: any;
    isNil: any;
    isNumber: any;
    isNull: any;
    isObject: any;
    isString: any;
    isUndefined: any;
    capitalize: any;
    reduce: any;
    filter: any;
    reject: any;
    has: any;
    map: any;
    forEach: any;
    includes: any;
    size: any;
    join: any;
    trimEnd: any;
    findIndex: any;
    get: any;
    every: any;
    keys: any;
    mapKeys: any;
    pickBy: any;
    value: any;
    unset: any;
    transform: any;
    startsWith: any;
    endsWith: any;
};
export = _exports;
